@@ -108,7 +108,8 @@ class RPSLIPv4PrefixField(RPSLTextField):
             parsed_ip_str += '/32'
         if parsed_ip_str != value:
             messages.info(f'Address prefix {value} was reformatted as {parsed_ip_str}')
-        return RPSLFieldParseResult(parsed_ip_str, ip_first=ip.net(), ip_last=ip.broadcast())
+        return RPSLFieldParseResult(parsed_ip_str, ip_first=ip.net(), ip_last=ip.broadcast(),
+                                    prefix=ip, prefix_length=ip.prefixlen())
 
 
 class RPSLIPv4PrefixesField(RPSLFieldListMixin, RPSLIPv4PrefixField):
@@ -135,7 +136,8 @@ class RPSLIPv6PrefixField(RPSLTextField):
             parsed_ip_str += '/128'
         if parsed_ip_str != value:
             messages.info(f'Address prefix {value} was reformatted as {parsed_ip_str}')
-        return RPSLFieldParseResult(parsed_ip_str, ip_first=ip.net(), ip_last=ip.broadcast())
+        return RPSLFieldParseResult(parsed_ip_str, ip_first=ip.net(), ip_last=ip.broadcast(),
+                                    prefix=ip, prefix_length=ip.prefixlen())
 
 
 class RPSLIPv6PrefixesField(RPSLFieldListMixin, RPSLIPv6PrefixField):
@@ -151,6 +153,7 @@ class RPSLIPv4AddressRangeField(RPSLTextField):
     not have to align to bitwise boundaries of prefixes.
     """
     def parse(self, value: str, messages: RPSLParserMessages, strict_validation=True) -> Optional[RPSLFieldParseResult]:
+        value = value.replace(',', '')  # #311, process multiline PK correctly
         if '-' in value:
             ip1_input, ip2_input = value.split('-', 1)
         else:
@@ -374,7 +377,7 @@ class RPSLGenericNameField(RPSLTextField):
 
     If non_strict_allow_any is set, the parser will allow any value if strict_validation
     is disabled. This is needed on nic-hdl for legacy reasons -
-    see https://github.com/irrdnet/irrd4/issues/60
+    see https://github.com/irrdnet/irrd/issues/60
     """
     keep_case = False
 
@@ -494,7 +497,7 @@ def parse_set_name(prefixes: List[str], value: str, messages: RPSLParserMessages
     prefix_display = '/'.join(prefixes)
 
     if strict_validation and len(input_components) > 5:
-        messages.error(f'Set names can have a maximum of five components.')
+        messages.error('Set names can have a maximum of five components.')
         return None
 
     if strict_validation and not any([c.upper().startswith(tuple(prefixes)) for c in input_components]):
