@@ -16,6 +16,7 @@ SAMPLE_AS_SET = """as-set:         AS-SETTEST
 descr:          description
 members:        AS65538, AS65539
 members:        AS65537
+members:        AS-OTHERSET
 tech-c:         PERSON-TEST
 admin-c:        PERSON-TEST
 notify:         notify@example.com
@@ -44,7 +45,7 @@ export:         to AS3549 announce AS-SETTEST
 import:         from AS3549 accept ANY
 export:         to AS9002 announce AS-SETTEST
 import:         from AS9002 accept ANY
-mp-export:      afi ipv6.unicast to AS9002 anunce AS-SETTEST
+mp-export:      afi ipv6.unicast to AS9002 announce AS-SETTEST
 mp-import:      afi ipv6.unicast from AS9002 accept ANY
 remarks:        ---> Peers
 export:         to AS31117 announce AS-SETTEST AS-UAIX
@@ -159,7 +160,6 @@ filter:         {
                 127.0.0.0/8^- ,
                 169.254.0.0/16^- ,  # The next two lines were introduced to test blank lines with correct cont. chars
                 172.16.0.0/12^- ,   # Note that the trailing whitespace is significant.
-                
 \t               
 +               
                 192.0.2.0/24^- ,
@@ -224,7 +224,7 @@ owner:          keybase.io/mxsasha <mxsasha@keybase.io>
 owner:          Sasha Romijn <gpg@mxsasha.eu>
 fingerpr:       8626 1D8D BEBD A4F5 4692  D64D A838 3BA7 80F2 38C6
 certif:         -----BEGIN PGP PUBLIC KEY BLOCK-----
-+               
+                
                 mQINBFnY7YoBEADH5ooPsoR9G/dNxrdHRMJeDHXCSQbwgXWEez5/F8/BZKV9occ/
 certif:         jZ7w2wH+Ghj4vTQl1DhuNcxi60qDv9DAPxG73DkBrK0I3fDUJUPrdOKW9SXvZCAq
 certif:         LrVEdDVH+YEKhQLlGG7DTODGsfMglL98mn7GD/wD64LtRF3eBAucTIjaOl9hvoqX
@@ -562,6 +562,7 @@ mnt-by:         TEST-MNT
 changed:        changed@example.com 20190701 # comment
 source:         TEST
 remarks:        remark
+rpki-ov-state: valid  # should be discarded
 """
 
 SAMPLE_ROUTE_SET = """route-set:      RS-TEST
@@ -570,6 +571,7 @@ mbrs-by-ref:    TEST-MNT
 tech-c:         PERSON-TEST
 admin-c:        PERSON-TEST
 mnt-by:         TEST-MNT
+members:        RS-OTHER-SET
 mp-members:     2001:0dB8::/48
 changed:        changed@example.com 20190701 # comment
 source:         TEST
@@ -613,7 +615,7 @@ changed:        changed@example.com 20190701 # comment
 source:         TEST
 """
 
-# https://github.com/irrdnet/irrd4/issues/232
+# https://github.com/irrdnet/irrd/issues/232
 SAMPLE_LEGACY_IRRD_ARTIFACT = """*xxte:          192.0.2.0/24
 origin:         AS65537
 mnt-by:         TEST-MNT
@@ -630,7 +632,6 @@ source:         TEST
 
 SAMPLE_MISSING_MANDATORY_ATTRIBUTE = """route:          192.0.2.0/24
 origin:         AS65537
-mnt-by:         TEST-MNT
 source:         TEST
 """
 
@@ -823,7 +824,7 @@ roa-uri:        [optional]   [single]    []
 remarks:        [optional]   [multiple]  []
 notify:         [optional]   [multiple]  []
 mnt-by:         [mandatory]  [multiple]  [look-up key, strong references mntner]
-changed:        [mandatory]  [multiple]  []
+changed:        [optional]   [multiple]  []
 source:         [mandatory]  [single]    []
 """
 
@@ -836,6 +837,6 @@ nic-hdl:   [mandatory]  [single]    [primary/look-up key]
 remarks:   [optional]   [multiple]  []
 notify:    [optional]   [multiple]  []
 mnt-by:    [mandatory]  [multiple]  [look-up key, strong references mntner]
-changed:   [mandatory]  [multiple]  []
+changed:   [optional]   [multiple]  []
 source:    [mandatory]  [single]    []
 """
